@@ -10,6 +10,7 @@ import re
 from dateutil.parser import parse
 
 from .drb_xquery_item import DrbXqueryItem
+from .drb_xquery_res_to_string import XQueryResToString
 from .drb_xquery_utils import DrbQueryFuncUtil
 from .execptions import DynamicException, ErrorXQUERY
 
@@ -236,6 +237,43 @@ def get_namespace_uri(func, current_node, static_context, elt=None):
     return static_context.get_namespace_full_name(elt.namespace_uri)
 
 
+def drb_xml(func, current_node, static_context, elt=None):
+    if elt is None:
+        elt = current_node
+    elif isinstance(elt, list):
+        if len(elt) == 0:
+            return ''
+        result = drb_xml(func, current_node, static_context, elt[0])
+        for item in elt[1:]:
+            result += ' ' + drb_xml(func, current_node, static_context, item)
+        return result
+
+    if isinstance(elt, DrbNode):
+        return XQueryResToString.drb_node_to_xml(
+            elt.node,
+            namespace_declared=[],
+            dynamic_context=None,
+            context=static_context)
+    elif isinstance(elt, DynamicContext):
+        if elt.is_node():
+            return XQueryResToString.drb_node_to_xml(
+                elt.node,
+                context=static_context,
+                namespace_declared=[],
+                dynamic_context=elt)
+        elif elt.is_attribute():
+            return XQueryResToString.drb_attribute_to_xml(
+                elt,
+                context=static_context,
+                namespace_declared=[],
+                dynamic_context=elt)
+        elif elt.name is not None and len(elt.name) > 0:
+            return f'<{elt.name}>{DrbQueryFuncUtil.get_string(elt)}' \
+                     f'</{elt.name}>'
+
+    return DrbQueryFuncUtil.get_string(elt)
+
+
 def is_empty_list(elt1):
     if isinstance(elt1, list) and len(elt1) == 0:
         return True
@@ -1152,6 +1190,10 @@ class DrbQueryFuncCall:
         'exp': math_exp,
     }
 
+    drb_func = {
+        'xml': drb_xml,
+    }
+
     xs_type_func = {
         'short': xs_int,
         'double': xs_float,
@@ -1208,6 +1250,7 @@ class DrbQueryFuncCall:
         context.set_func_list_namespace('fn', DrbQueryFuncCall.xpath_func)
         context.set_func_list_namespace('xs', DrbQueryFuncCall.xs_type_func)
         context.set_func_list_namespace('math', DrbQueryFuncCall.math_func)
+        context.set_func_list_namespace('drb', DrbQueryFuncCall.drb_func)
 
         context.namespace_default_func = 'fn'
         # "http://www.w3.org/2005/xpath-functions"
