@@ -1,9 +1,16 @@
+import re
+
+from xml.etree.ElementTree import ElementTree
+
+from drb_impl_xml import XmlNode
 from typing import Dict, Tuple, Any, List, Optional
 
 from drb import DrbNode, AbstractNode
 from drb.exceptions import DrbNotImplementationException, DrbException
 from drb.path import ParsedPath
 
+from drb_xquery.drb_xquery_context import StaticContext, DynamicContext
+
 
 class DrbXqueryItem(AbstractNode):
 
@@ -116,3 +123,10 @@ class DrbXqueryItem(AbstractNode):
     def __ne__(self, other):
         """Overrides the default implementation (unnecessary in Python 3)"""
         return not self.__eq__(other)
+
+    def __repr__(self):
+        from drb_xquery.drb_xquery_res_to_string import XQueryResToString
+        return XQueryResToString.drb_item_to_xml(self,
+                                                 context=None,
+                                                 dynamic_context=None,
+                                                 namespace_declared=[])
