@@ -210,6 +210,19 @@ class TestDrbXQuery(unittest.TestCase):
         self.assertEqual(len(node_result), 1)
         self.assertEqual(node_result[0].value, "2")
 
+    def test_xquery_attribute_value(self):
+        self.node_file = DrbFileFactory().create(self.xml_file)
+        self.node = XmlNodeFactory().create(self.node_file)
+
+        query = DrbXQuery(
+            "data(/Level-2A_Tile_ID/General_Info/@month)")
+
+        node_result = query.execute(self.node)
+
+        print("len :" + str(len(node_result)))
+        self.assertEqual(len(node_result), 2)
+        self.assertEqual(node_result[0], "01")
+
     def test_xquery_namespace(self):
         self.node_file = DrbFileFactory().create(self.xml_file)
         self.node = XmlNodeFactory().create(self.node_file)
@@ -437,7 +450,7 @@ class TestDrbXQuery(unittest.TestCase):
 
         list_var = {'x': 2}
 
-        node_result = query.execute(self.node, list_var)
+        node_result = query.execute(self.node, **list_var)
 
         self.assertEqual(len(node_result), 1)
         self.assertEqual(node_result[0], 3)
@@ -451,7 +464,7 @@ class TestDrbXQuery(unittest.TestCase):
         list_var = {'y': 2}
 
         with self.assertRaises(Exception) as error:
-            node_result = query.execute(self.node, list_var)
+            node_result = query.execute(self.node, **list_var)
         self.assertIn("XPDY0002", str(error.exception))
 
     def test_xquery_external_var_default_not_defined(self):
@@ -463,7 +476,7 @@ class TestDrbXQuery(unittest.TestCase):
 
         list_var = {'x': 9}
 
-        node_result = query.execute(self.node, list_var)
+        node_result = query.execute(self.node, **list_var)
 
         self.assertEqual(len(node_result), 1)
         self.assertEqual(node_result[0], 14)
@@ -475,9 +488,7 @@ class TestDrbXQuery(unittest.TestCase):
         query = DrbXQuery("declare variable $x external; "
                           "declare variable $y external := 5; $x+$y")
 
-        list_var = {'x': 9, 'y': 12}
-
-        node_result = query.execute(self.node, list_var)
+        node_result = query.execute(None, x=9, y=12)
 
         self.assertEqual(len(node_result), 1)
         self.assertEqual(node_result[0], 21)
@@ -508,3 +519,23 @@ class TestDrbXQuery(unittest.TestCase):
         node_result = drb_query.execute(None)
 
         self.assertListEqual(node_result, [False, True])
+
+    def test_xquery_list_node(self):
+        self.node_file = DrbFileFactory().create(self.xml_file)
+        self.node = XmlNodeFactory().create(self.node_file)
+        xml_file_b = self.current_path / "files" / "MTD_TL_Bis.xml"
+        node_file_b = DrbFileFactory().create(xml_file_b)
+        node_b = XmlNodeFactory().create(node_file_b)
+
+        query = DrbXQuery("/nc3:Level-2A_Tile_ID/(nc3:Test_num[1], "
+                          "nc3:Test_FLF[1])")
+
+        node_result = query.execute(self.node, node_b)
+
+        self.assertEqual(len(node_result), 4)
+
+        self.assertEqual(node_result[1].node['name'].value, 'first')
+
+        node_b.close()
+        node_file_b.close()
+        node_file_b.close()
