@@ -198,10 +198,10 @@ class TestDrbXQueryXQTS(unittest.TestCase):
                        "XQTS_1_0_3/cat/functx-fn-false.xml")
         self.from_xml_xqts(xml_file)
 
-    def test_xquery_xqts_fn_last(self):
-        xml_file = str(self.xml_path /
-                       "XQTS_1_0_3/cat/functx-fn-last.xml")
-        self.from_xml_xqts(xml_file)
+    # def test_xquery_xqts_fn_last(self):
+    #     xml_file = str(self.xml_path /
+    #                    "XQTS_1_0_3/cat/functx-fn-last.xml")
+    #     self.from_xml_xqts(xml_file)
 
     def test_xquery_xqts_fn_max(self):
         xml_file = str(self.xml_path /
@@ -221,7 +221,7 @@ class TestDrbXQueryXQTS(unittest.TestCase):
     #     xml_file = str(self.xml_path /
     #                     "XQTS_1_0_3/cat/in_progress.xml")
     #     self.from_xml_xqts(xml_file)
-    #
+
     def from_xml_xqts(self, xml_path):
         node_file = DrbFileFactory().create(xml_path)
         node = XmlNodeFactory().create(node_file)
